pub enum RemoveNoteOutcome {
Removed {
notes_commit: ObjectId,
},
Unchanged,
}Expand description
Result of an incremental note removal at the repository level.
Variants
Removed
One or more notes were removed and the notes ref advanced.
Unchanged
The notes ref was absent or none of the requested annotated objects had notes.