pub enum UpsertNoteOutcome {
Updated {
notes_commit: ObjectId,
},
Unchanged,
}Expand description
Result of an incremental note upsert at the repository level.
Variants
Updated
A new or updated note was written and the notes ref advanced.
Unchanged
The annotated object already referenced this blob; no objects or ref were written.