pub fn read_note(
git_dir: &Path,
format: ObjectFormat,
store: &FileRefStore,
notes_ref: &NotesRef,
annotated: &ObjectId,
) -> Result<Option<ObjectId>>Expand description
Return the note blob oid for annotated, if any.
pub fn read_note(
git_dir: &Path,
format: ObjectFormat,
store: &FileRefStore,
notes_ref: &NotesRef,
annotated: &ObjectId,
) -> Result<Option<ObjectId>>Return the note blob oid for annotated, if any.