pub fn finalize_notes_merge(
git_dir: &Path,
format: ObjectFormat,
store: &FileRefStore,
notes_ref: &NotesRef,
partial_commit: ObjectId,
resolved: &[(ObjectId, Vec<u8>)],
identity: &NotesCommitIdentity,
) -> Result<ObjectId>Expand description
Finalize a previous conflicting notes merge by adding resolved worktree entries to the partial notes tree and creating the final merge commit.